@@ -16,8 +16,8 @@
 
 #include "vocabularymimedata.h"
 
-#include <keduvoctranslation.h>
-#include <keduvocwordtype.h>
+#include <KEduVocTranslation>
+#include <KEduVocWordtype>
 
 
 void VocabularyMimeData::setTranslations(const QList<KEduVocTranslation *> &translations)
