@@ -14,10 +14,10 @@
 
 #include "declensionwidget.h"
 
-#include <keduvocdocument.h>
-#include <keduvocexpression.h>
-#include <keduvocwordtype.h>
-#include <keduvocdeclension.h>
+#include <KEduVocDocument>
+#include <KEduVocExpression>
+#include <KEduVocWordtype>
+#include <KEduVocDeclension>
 
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -35,11 +35,7 @@ DeclensionWidget::DeclensionWidget(QWidget *parent) : QWidget(parent)
     numberSelection->setItemData(0, KEduVocWordFlag::Singular);
     numberSelection->setItemData(1, KEduVocWordFlag::Dual);
     numberSelection->setItemData(2, KEduVocWordFlag::Plural);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(numberSelection, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &DeclensionWidget::updateEntries);
-#else
-    connect(numberSelection, static_cast<void (QComboBox::*)(int, const QString &)>(&QComboBox::currentIndexChanged) , this, &DeclensionWidget::updateEntries);
-#endif
 
     connect(nextButton, &QPushButton::clicked, this, &DeclensionWidget::nextNumber);
 
