@@ -26,7 +26,7 @@
 class ScriptDialog : public QDialog
 {
 public:
-    ScriptDialog(ScriptManager* scriptManager);
+    explicit ScriptDialog(ScriptManager* scriptManager);
     ~ScriptDialog();
     /**
      * Executed when user clicks OK button.
@@ -38,7 +38,7 @@ public:
 private:
     KPluginSelector* m_kps;
     QList<KPluginInfo> pluginsInfoList;
-    KConfigGroup* scriptsConfigGroup;
+//    KConfigGroup* scriptsConfigGroup;
     ScriptManager* m_scriptManager;
 
 };
