@@ -48,26 +48,26 @@ protected slots:
     /**
      * Called when the user clicks Apply or OK.
      */
-    void updateSettings();
+    void updateSettings() Q_DECL_OVERRIDE;
     /**
      * Updates dialog widgets. Here only used after loading a profile.
      * Profiles only store the settings of the last three pages in the dialog.
      */
-    void updateWidgets();
+    void updateWidgets() Q_DECL_OVERRIDE;
     /**
      * Called when the user clicks Default
      */
-    void updateWidgetsDefault();
+    void updateWidgetsDefault() Q_DECL_OVERRIDE;
 
 protected:
     /**
      * Returns true if the current state of the dialog is different from the saved settings
      */
-    bool hasChanged();
+    bool hasChanged() Q_DECL_OVERRIDE;
     /**
      * Returns true if the current state of the dialog represents the default settings.
      */
-    bool isDefault();
+    bool isDefault() Q_DECL_OVERRIDE;
 
 private:
     GeneralOptions * m_generalOptions;
