@@ -30,7 +30,7 @@ class ViewOptions : public QWidget, public Ui::ViewOptionsBase
 {
     Q_OBJECT
 public:
-    ViewOptions(QWidget* parent = 0);
+    explicit ViewOptions(QWidget* parent = 0);
 };
 
 #endif
